==> fusiondirectory_1.2.3.orig-core.tar.gz: fusiondirectory-1.2.3/AUTHORS.md <==
FusionDirectory AUTHORS
=======================

This is the alphabetical list of all people that have
contributed to the FusionDirectory project, beeing code, translations,
documentation and additional help.

* Markus Amersdorfer <der.plusch@subnet.at>
  Wiki setup, Testing, hints, proposals

* Alessandro Amici <a.amici@bopen.it>
  Italian translation

* Holger Burbach <burbach@gonicus.de>
  Kerberos PHP module

* Craig Chang <craig0310@gmail.com>
  Fixes for magic_quotes_qpc

* Guillaume Delecourt <guillaume.delecourt@opensides.be>
  Setup fixes, nagios tab plugin, xls addons ldapmanager
  pptp connectivity option, phpscheduleit connectivity option

* Dan Ellis <danellis@rushmore.com>
  Sieve lib is taken from him

* Alejandro Escanero Blanco <aescanero@chaosdimension.org>
  Fixes, improvements, translation, netgroup plugin, Guide and some extensions

* Fabian Hickert <hickert@gonicus.de>
  Improvements for setup, various fixes and plugins

* Eric Kilfoil <eric@ipass.net>
  ldap.inc is taken from him

* Niels Klomp <nk@careworks.nl>
  Dutch translation

* Steve Moitozo <god at zilla dot us>
  Password checker

* Benoit Mortier <benoit.mortier@opensides.be>
  Butracking, QA, French translation

* Igor Muratov <migor@altlinux.org>
  Various fixes and speed enhancements

* Michael Pasdziernik <mp@secio.de>
  Documentation for GOsa and safe-mode, fixes

* Cajus Pollmeier <pollmeier@gonicus.de>
  Virtually everyting which is GOsa related

* Piotr Rybicki <meritus@innervision.pl>
  Polish translation

* Henning Schmiedehausen <hps@intermeta.de>
  Various fixes, support for user defined people/group base

* Alfred Schröder <schroeder@gonicus.de>
  German translation

* Thomas Schüßler <tulpe@atomar.de>
  debuglib.inc is taken from him

* Jan Wenzel <jan.wenzel@gonicus.de>
  Implementation and research for samba munged dial support,
  fixing of "Fiptehlers"(TM) in the german translations.

* Leila El Hitori <leila.elhitori@opensides.be>
  French online documentation
  English online documentation

* Vincent Seynhaeve <vincent.seynhaeve@opensides.be>
  Xls export plugin 

* Wouter Verhelst <wouter@debian.org>
  accept-to-gettext code that helps for language conversation

* Antoine Gallavardin <antoine.gallavardin@free.fr>
  Dhcp plugin patch to manage key and update zone in dhcp for dyndns
  First version of the quota and supann plugin
  First version of the board plugin

* Leonid Bogdanov <leonid_bogdanov@mail.ru>
  patch for the manager fonctionnality in the General user tab

* Olivier BONHOMME <obonhomme@nerim.net>
  Fedora and Centos Packager, selinux policy creator

* Benjamin Carpentier <carpentierbenjamin@gmail.com>
  Tested FusionDirectory, corrected copyright issues and locales
  Written fusiondirectory-setup

* Giuliano Di Vito <guiliano@opensides.be>
  Italian Translator and bug finder

* Roman Widmann <archme.mail@gmail.com>
  Arch linux packager

* Bernigaud Côme <come.bernigaud@laposte.net>
  New daemon code class_supportDaemon.inc, and all the new deployment stuff :)
  Simple plugin framework developper

* Alexis Michon <alexis.michon@ibcp.fr>
  Testing, First version of Password reset

* Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
  Various patches from debian-edu
  Apache 2.4 support
  Mcrypt decrypt enhancement
  Browsing inactive tab 

* Jeremy Williame <williamejeremy@hotmail.com>
  Cleanup and writer of the FusionDirectory doxygen api documentation

* Rudy Hardeman <zarya@gigafreak.net>
  Option to remove sambaLMpassword storage

* Gaston Tjebbes
  Feth Arezki <feth@majerti.fr>
  First version of the autofs plugin

* Daniel B <daniel@firewall-services.com>
  Cleanup of the sambaPwdMustChange, sambaPwdCanChange

* Regis patronix <regis.patroix@thecosmocompany.com>
  Allow special characters in passwords

* Sergio Talens-Oliag <sto@iti.es>
  Configuration setting to force the use of a hash when setting or changing passwords
  Add support for crypt/sha-256 and crypt/sha-512
  Use the passwordDefaultHash for new users
  Fix for icons in core plugins
  Provide a way to show hook execution results to the user via web
  Hide userPassword on change_password postmodfy hook error message

* Stefan Krüger <shadow_7@gmx.net>
  Add support for various database to the rsyslog plugin

* Guillaume Chéramy <guillaume@cheramy.name>
  Patches for the template system

* Mathias Friman mathias.friman@knorca.se
  Translation to swedish

* Alexandre Magnat <alexandre.magnat@mecaprotec.fr>
  Snapshot bug reporter

* Guillaume RODRIGUEZ <rodriguez.guillaume@icloud.com>
  asterisk plugin error reporter

* Guillard Olivier <fd@guillard.nom.fr>
  SSH plugin key storage problem reporter

* Fabien Brachere <fabien.brachere@e-tera.com>
  Fix support for special caracters in password

* Arnaud Patard <apatard@hupstream.com>
  Fix for Invalid uri in the password recovery mail
  Fix for start tls on fusiondirectory setup and gnutls

* Adrian Reyer <are+fd@lihas.de>
  Modifier for templates to convert german umlauts to 7-bit ASCII

* Samuel Bosquin <samuel.bosquin@ibcp.fr>
  Plugin FAI - LVM partitions

* IOhannes umlaeute <noc@iem.at>
  generateLdif() fails with bind-passwords containg '$' patch
  
* Karsten Becker <karsten.becker@ecologic.eu>
  Suse install from tarballs Documentation

* Felix Weissbeck <contact-fusiondirectory@w7k.de>
  Method to add a change password dialog on sasl+kerberos
  
* Tobias Göbel
  Fixes for PHP7 compatibility

* Christian Kreidl <christian.kreidl@ziti.uni-heidelberg.de>
  ppolicy improvement
  
* Martin Hamant <mh@ow2.org>
  Coded the LockUser fonction for the webservice
  
* Jonathan Swaelens <jonathan@opensides.be>
  QA on FusionDirectory
  RPM packaging maintener and ArchLinux Packager
  
* Timothée Giet <timo@timotheegiet.com>
  New breezy icon Theme

* Clement Oudot <clem.oudot@gmail.com>
  HTTP header authentication
  Password expiration date in dashboard

* Thomas Niercke <thomas@niercke.de>
  Code and ideas for making Argonaut Events Extensible
  
* Paola Penati <paolapenati@hotmail.com>
  Italian translation of FusionDirectory and the website

* Martin Hamant <mh@ow2.org>
  Adding DSA accounts into groups
  
* Mathias Soupault <mathias.soupault@inalco.fr>
  Making supannAliasLogin usage possible in password recovery

* Patzke Thomas <thomas.patzke2@thyssenkrupp.com>
  Security and vulnerabitity testing

==> fusiondirectory_1.3.orig-core.tar.gz: fusiondirectory-1.3/AUTHORS.md <==
FusionDirectory AUTHORS
=======================

This is the alphabetical list of all people that have
contributed to the FusionDirectory project, beeing code, translations,
documentation and additional help.

* Markus Amersdorfer <der.plusch@subnet.at>
  Wiki setup, Testing, hints, proposals

* Alessandro Amici <a.amici@bopen.it>
  Italian translation

* Holger Burbach <burbach@gonicus.de>
  Kerberos PHP module

* Craig Chang <craig0310@gmail.com>
  Fixes for magic_quotes_qpc

* Guillaume Delecourt <guillaume.delecourt@opensides.be>
  Setup fixes, nagios tab plugin, xls addons ldapmanager
  pptp connectivity option, phpscheduleit connectivity option

* Dan Ellis <danellis@rushmore.com>
  Sieve lib is taken from him

* Alejandro Escanero Blanco <aescanero@chaosdimension.org>
  Fixes, improvements, translation, netgroup plugin, Guide and some extensions

* Fabian Hickert <hickert@gonicus.de>
  Improvements for setup, various fixes and plugins

* Eric Kilfoil <eric@ipass.net>
  ldap.inc is taken from him

* Niels Klomp <nk@careworks.nl>
  Dutch translation

* Steve Moitozo <god at zilla dot us>
  Password checker

* Benoit Mortier <benoit.mortier@opensides.be>
  Butracking, QA, French translation

* Igor Muratov <migor@altlinux.org>
  Various fixes and speed enhancements

* Michael Pasdziernik <mp@secio.de>
  Documentation for GOsa and safe-mode, fixes

* Cajus Pollmeier <pollmeier@gonicus.de>
  Virtually everyting which is GOsa related

* Piotr Rybicki <meritus@innervision.pl>
  Polish translation

* Henning Schmiedehausen <hps@intermeta.de>
  Various fixes, support for user defined people/group base

* Alfred Schröder <schroeder@gonicus.de>
  German translation

* Thomas Schüßler <tulpe@atomar.de>
  debuglib.inc is taken from him

* Jan Wenzel <jan.wenzel@gonicus.de>
  Implementation and research for samba munged dial support,
  fixing of "Fiptehlers"(TM) in the german translations.

* Leila El Hitori <leila.elhitori@opensides.be>
  French online documentation
  English online documentation

* Vincent Seynhaeve <vincent.seynhaeve@opensides.be>
  Xls export plugin 

* Wouter Verhelst <wouter@debian.org>
  accept-to-gettext code that helps for language conversation

* Antoine Gallavardin <antoine.gallavardin@free.fr>
  Add support for social network ORCID in personal
  Dhcp plugin patch to manage key and update zone in dhcp for dyndns
  First version of the quota plugin
  First version of the supann plugin
  First version of the board plugin

* Leonid Bogdanov <leonid_bogdanov@mail.ru>
  patch for the manager fonctionnality in the General user tab

* Olivier BONHOMME <obonhomme@nerim.net>
  Fedora and Centos Packager, selinux policy creator

* Benjamin Carpentier <carpentierbenjamin@gmail.com>
  Tested FusionDirectory, corrected copyright issues and locales
  Written fusiondirectory-setup

* Giuliano Di Vito <guiliano@opensides.be>
  Italian Translator and bug finder

* Roman Widmann <archme.mail@gmail.com>
  Arch linux packager

* Bernigaud Côme <come.bernigaud@laposte.net>
  New daemon code class_supportDaemon.inc, and all the new deployment stuff :)
  Simple plugin framework developper

* Alexis Michon <alexis.michon@ibcp.fr>
  Testing, First version of Password reset
  Support for two or more MAC address for a system

* Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
  Various patches from debian-edu
  Apache 2.4 support
  Mcrypt decrypt enhancement
  Browsing inactive tab 

* Jeremy Williame <williamejeremy@hotmail.com>
  Cleanup and writer of the FusionDirectory doxygen api documentation

* Rudy Hardeman <zarya@gigafreak.net>
  Option to remove sambaLMpassword storage

* Gaston Tjebbes
  Feth Arezki <feth@majerti.fr>
  First version of the autofs plugin

* Daniel B <daniel@firewall-services.com>
  Cleanup of the sambaPwdMustChange, sambaPwdCanChange

* Regis patronix <regis.patroix@thecosmocompany.com>
  Allow special characters in passwords

* Sergio Talens-Oliag <sto@iti.es>
  Configuration setting to force the use of a hash when setting or changing passwords
  Add support for crypt/sha-256 and crypt/sha-512
  Use the passwordDefaultHash for new users
  Fix for icons in core plugins
  Provide a way to show hook execution results to the user via web
  Hide userPassword on change_password postmodfy hook error message

* Stefan Krüger <shadow_7@gmx.net>
  Add support for various database to the rsyslog plugin

* Guillaume Chéramy <guillaume@cheramy.name>
  Patches for the template system

* Mathias Friman mathias.friman@knorca.se
  Translation to swedish

* Alexandre Magnat <alexandre.magnat@mecaprotec.fr>
  Snapshot bug reporter

* Guillaume RODRIGUEZ <rodriguez.guillaume@icloud.com>
  asterisk plugin error reporter

* Guillard Olivier <fd@guillard.nom.fr>
  SSH plugin key storage problem reporter

* Fabien Brachere <fabien.brachere@e-tera.com>
  Fix support for special caracters in password

* Arnaud Patard <apatard@hupstream.com>
  Fix for Invalid uri in the password recovery mail
  Fix for start tls on fusiondirectory setup and gnutls

* Adrian Reyer <are+fd@lihas.de>
  Modifier for templates to convert german umlauts to 7-bit ASCII

* Samuel Bosquin <samuel.bosquin@ibcp.fr>
  Plugin FAI - LVM partitions

* IOhannes umlaeute <noc@iem.at>
  generateLdif() fails with bind-passwords containg '$' patch
  
* Karsten Becker <karsten.becker@ecologic.eu>
  Suse install from tarballs Documentation

* Felix Weissbeck <contact-fusiondirectory@w7k.de>
  Method to add a change password dialog on sasl+kerberos
  
* Tobias Göbel
  Fixes for PHP7 compatibility

* Christian Kreidl <christian.kreidl@ziti.uni-heidelberg.de>
  ppolicy improvement
  
* Martin Hamant <mh@ow2.org>
  Coded the LockUser fonction for the webservice
  
* Jonathan Swaelens <jonathan@opensides.be>
  QA on FusionDirectory
  RPM packaging maintener and ArchLinux Packager
  
* Timothée Giet <timo@timotheegiet.com>
  New breezy icon Theme

* Clement Oudot <clem.oudot@gmail.com>
  HTTP header authentication
  Password expiration date in dashboard

* Thomas Niercke <thomas@niercke.de>
  Code and ideas for making Argonaut Events Extensible
  
* Paola Penati <paolapenati@hotmail.com>
  Italian translation of FusionDirectory and the website

* Martin Hamant <mh@ow2.org>
  Adding DSA accounts into groups
  
* Mathias Soupault <mathias.soupault@inalco.fr>
  Making supannAliasLogin usage possible in password recovery

* Patzke Thomas <thomas.patzke2@thyssenkrupp.com>
  Security and vulnerabitity testing

* Janne Heß
  Enhance the login and password reset theme

* Peter Linss
  Added catchall table to postfix plugin

* Renato Ramonda
  Support for SSH ed25519 keys
